<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>Cmd</name>
    <message>
        <location filename="../src/cmd.cpp" line="163"/>
        <source>Administrator Access Required</source>
        <translation>Rendszergazdai jogosultság szükséges</translation>
    </message>
    <message>
        <location filename="../src/cmd.cpp" line="164"/>
        <source>This operation requires administrator privileges. Please restart the application and enter your password when prompted.</source>
        <translation>Ehhez a művelethez rendszergazdai jogosultságok kellenek. Kérjük, indítsa újra az alkalmazást, és adja meg a jelszavát, amikor kéri.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="57"/>
        <location filename="../src/mainwindow.ui" line="198"/>
        <source>Please select the location of your installation:</source>
        <translation>Válassza ki a telepített rendszer helyét:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="71"/>
        <location filename="../src/mainwindow.ui" line="211"/>
        <source>Select drive:</source>
        <translation>Meghajtó kiválasztása:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="78"/>
        <location filename="../src/mainwindow.ui" line="228"/>
        <source>Select partition:</source>
        <translation>Partíció kiválasztása:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="249"/>
        <source>Frugal mode:</source>
        <translation>Lemezképként telepített:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="296"/>
        <source>Boot options:</source>
        <translation>Indítási paraméterek:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="129"/>
        <location filename="../src/mainwindow.ui" line="313"/>
        <source>UEFI entry name:</source>
        <translation>UEFI bejegyzés neve:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="20"/>
        <source>UEFI manager</source>
        <translation>UEFI kezelő</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="41"/>
        <source>EFI stub installer</source>
        <translation>EFI-csonk telepítő</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="47"/>
        <source>This options copies the kernel and initrd files to ESP (EFI System Partition) and creates an UEFI entry that allows to boot the installation directly, bypassing GRUB and other bootloaders. To boot using the created UEFI entry, access the UEFI boot selection menu at startup by pressing the appropriate key for your device (e.g., F12, F9, or Esc, depending on the manufacturer).</source>
        <translation>Ez az opció a kernel és az initrd fájlokat az ESP-be másolja (EFI rendszerpartíció), és létrehoz egy UEFI-bejegyzést, amely lehetővé teszi a telepítés közvetlen indítását, megkerülve a GRUB és más rendszerbetöltők használatát. A létrehozott UEFI-bejegyzés használatával történő indításhoz, indításkor az eszköznek megfelelő billentyű megnyomásával (pl. F12, F9 vagy Esc, gyártótól függően) lépjen be az UEFI rendszerindítási választó menübe.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="115"/>
        <source>Kernel to boot:</source>
        <translation>Indítandó kernel:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="122"/>
        <source>Kernel options:</source>
        <translation>Kernel opciók:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="393"/>
        <source>About this application</source>
        <translation>Az alkalmazásról</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="396"/>
        <source>About...</source>
        <translation>Névjegy...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="402"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="418"/>
        <source>Quit application</source>
        <translation>Kilépés az alkalmazásból</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="421"/>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="427"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="443"/>
        <source>Display help </source>
        <translation>Súgó megjelenítése</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="36"/>
        <source>Manage UEFI entries</source>
        <translation>UEFI bejegyzések kezelése</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="166"/>
        <source>Frugal EFI stub installer</source>
        <translation>Lemezképként telepítés EFI csonka indító</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="172"/>
        <source>This option is meant to create a bootable entry for MX and antiX frugal installation, it creates an EFI boot entry for launching the installation directly, bypassing GRUB and other bootloaders. To boot using the created UEFI entry, access the UEFI boot selection menu at startup by pressing the appropriate key for your device (e.g., F12, F9, or Esc, depending on the manufacturer).</source>
        <translation>Ez az opció az MX és antiX lemezképként telepítéséhez egy indítási bejegyzés létrehozására szolgál, létrehoz egy EFI rendszerindító bejegyzést a telepítés közvetlen elindításához, megkerülve a GRUB és más rendszerbetöltők használatát. A létrehozott UEFI-bejegyzéssel történő indításhoz, a bekapcsolás után az eszköznek megfelelő billentyűvel (pl. F12, F9 vagy Esc, gyártótól függően) lépjen be az UEFI rendszerindítási választó menübe.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="446"/>
        <source>Help</source>
        <translation>Súgó</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="452"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="465"/>
        <location filename="../src/mainwindow.cpp" line="885"/>
        <location filename="../src/mainwindow.cpp" line="1677"/>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="503"/>
        <source>Back</source>
        <translation>Vissza</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="718"/>
        <location filename="../src/mainwindow.cpp" line="908"/>
        <location filename="../src/mainwindow.cpp" line="1487"/>
        <location filename="../src/mainwindow.cpp" line="1497"/>
        <source>UEFI Installer</source>
        <translation>UEFI telepítő</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="719"/>
        <source>A recent frugal install has been detected. Do you wish to add a UEFI entry direct to your UEFI system menu?</source>
        <translation>Egy friss lemezképként telepített rendszer detektálva. Kívánja hozzáadni az UEFI rendszermenühöz a vonatkozó UEFI bejegyzést?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="956"/>
        <source>Could not retrieve UUID for %1</source>
        <translation>UUID beszerzése nem sikerült: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="963"/>
        <source>Enter passphrase to unlock %1 encrypted partition:</source>
        <translation>Adja meg a jelszót a %1 titkosított partíció feloldásához:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="968"/>
        <source>Passphrase entry cancelled or empty for %1</source>
        <translation>Jelszóbevitel megszakítva vagy üres jelszó ehhez: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="974"/>
        <source>Could not open %1 LUKS container</source>
        <translation>Nem sikerült a %1 LUKS konténer megnyitása</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1488"/>
        <source>Are you sure this is the MX or antiX Frugal installation location?
Missing mandatory files in directory: </source>
        <translation>Biztos benne, hogy ez az MX ill. antiX lemezképként telepített rendszer helye?
Szükséges fájlok hiányoznak a könyvtárban:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1561"/>
        <source>Not enough space on the EFI System Partition to copy the kernel and initrd files.</source>
        <translation>Nincs elég hely az EFI rendszerpartíción a kernel és az initrd fájlok másolásához.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1614"/>
        <source>All fields are required</source>
        <translation>Az összes mező megadása szükséges</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1637"/>
        <source>Could not select ESP</source>
        <translation>Az ESP kiválasztása nem sikerült</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1655"/>
        <source>About %1</source>
        <translation>%1 névjegye</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="130"/>
        <source>Select EFI file</source>
        <translation>Válassza ki az EFI fájlt</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="130"/>
        <source>EFI files (*.efi *.EFI)</source>
        <translation>EFI fájlok (*.efi, *.EFI)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="141"/>
        <location filename="../src/mainwindow.cpp" line="155"/>
        <location filename="../src/mainwindow.cpp" line="956"/>
        <location filename="../src/mainwindow.cpp" line="968"/>
        <location filename="../src/mainwindow.cpp" line="974"/>
        <location filename="../src/mainwindow.cpp" line="1697"/>
        <location filename="../src/mainwindow.cpp" line="1821"/>
        <location filename="../src/mainwindow.cpp" line="1873"/>
        <location filename="../src/mainwindow.cpp" line="1884"/>
        <location filename="../src/mainwindow.cpp" line="1891"/>
        <location filename="../src/mainwindow.cpp" line="1902"/>
        <location filename="../src/mainwindow.cpp" line="1912"/>
        <location filename="../src/mainwindow.cpp" line="1927"/>
        <location filename="../src/mainwindow.cpp" line="1932"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="141"/>
        <source>Could not find the source mountpoint for %1</source>
        <translation>Nem található a forrás csatolási pont ehhez: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="145"/>
        <source>Set name</source>
        <translation>Név beállítása</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="145"/>
        <source>Enter the name for the UEFI menu item:</source>
        <translation>Adja meg a nevet az UEFI menü elemhez:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="155"/>
        <source>Something went wrong, could not add entry.</source>
        <translation>Hiba történt, nem sikerült az elem hozzáadása.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="745"/>
        <location filename="../src/mainwindow.cpp" line="787"/>
        <location filename="../src/mainwindow.cpp" line="1709"/>
        <source>Timeout: %1 seconds</source>
        <translation>Időtúllépés: %1 másodperc</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="747"/>
        <location filename="../src/mainwindow.cpp" line="786"/>
        <location filename="../src/mainwindow.cpp" line="803"/>
        <location filename="../src/mainwindow.cpp" line="1726"/>
        <source>Boot Next: %1</source>
        <translation>Következő Indítása: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="749"/>
        <source>Boot Current: %1</source>
        <translation>Jelenlegi indítása: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="762"/>
        <source>You can use the Up/Down buttons, or drag &amp; drop items to change boot order.
- Items are listed in the boot order.
- Grayed out lines are inactive.</source>
        <translation>A fel és le gombokkal vagy húzd és ejtsd módszerrel rendezheti át az indítási sorrendet.
- Az elemek az indítás sorrendjében vannak.
- A szürke elemek nem aktívak.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="773"/>
        <location filename="../src/mainwindow.cpp" line="838"/>
        <source>Set ac&amp;tive</source>
        <translation>Aktívvá &amp;tétel</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="774"/>
        <source>&amp;Add entry</source>
        <translation>Elem hozzá&amp;adása</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="775"/>
        <source>Boot &amp;next</source>
        <translation>&amp;Következő indítása</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="776"/>
        <source>Move &amp;down</source>
        <translation>Mozgatás &amp;le</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="777"/>
        <source>&amp;Remove entry</source>
        <translation>Elem el&amp;távolítása</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="779"/>
        <source>Re&amp;set next</source>
        <translation>Következő &amp;visszaállítása</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="780"/>
        <source>Change &amp;timeout</source>
        <translation>Időtúllépés &amp;megváltoztatása</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="781"/>
        <source>Move &amp;up</source>
        <translation>Mozgatás &amp;fel</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="786"/>
        <location filename="../src/mainwindow.cpp" line="803"/>
        <source>not set, will boot using list order</source>
        <translation>nincs megadva, a lista sorrendjében indul</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="835"/>
        <source>Set &amp;inactive</source>
        <translation>&amp;Inaktívvá tétel</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="908"/>
        <source>Failed to open grub.entry file.</source>
        <translation>A grub.entry fájl megnyitása nem sikerült.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1658"/>
        <source>Tool for managing UEFI boot entries</source>
        <translation>Eszköz az UEFI rendszerindítási bejegyzések kezelésére.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1821"/>
        <source>Both old and new EFI labels must be specified</source>
        <translation>Mind a régi és az új UEFI címkéket meg kell adni</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1874"/>
        <source>Multiple boot entries found for label &apos;%1&apos;: %2 and %3;</source>
        <translation>Több indítási elem található ezzel a címkével: &apos;%1&apos;: %2 és %3;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1884"/>
        <source>No EFI data found for label &apos;%1&apos;.</source>
        <translation>Nincs EFI adat ehhez a címkéhez: &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1892"/>
        <source>EFI label &apos;%1&apos; is linked to an unknown partition &apos;%2&apos;.</source>
        <translation>A(z) &apos;%1&apos; EFI címke ismeretlen partícióhoz tartozik: &apos;%2&apos;.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1903"/>
        <source>Unexpected device name format &apos;%1&apos; for partition related to the label.</source>
        <translation>Váratlan eszköznév formátum: &apos;%1&apos;, a címkére vonatkozó partíciónak.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1913"/>
        <source>Device partition number [%1] differs from EFI entry partition number [%2].</source>
        <translation>Ez eszköz partíciószáma [%1] különbözik az EFI bejegyzés partíciószámától [%2].</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1927"/>
        <source>Failed to delete old boot entry</source>
        <translation>A régi indítási bejegyzés törlése nem sikerült</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1932"/>
        <source>Failed to create new boot entry</source>
        <translation>Az új indítási bejegyzés létrehozása nem sikerült</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1497"/>
        <source>Failed to read grub.entry file.</source>
        <translation>A grub.entry fájl olvasása nem sikerült.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="893"/>
        <location filename="../src/mainwindow.cpp" line="1510"/>
        <source>Install</source>
        <translation>Telepítés</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1516"/>
        <source>Select Frugal Directory</source>
        <translation>Válassza ki a lemezképként telepítés könyvtárát</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1523"/>
        <source>No EFI System Partitions found.</source>
        <translation>Nincs EFI rendszerpartíció.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1529"/>
        <source>Select EFI System Partition</source>
        <translation>Válassza ki az EFI rendszerpartíciót</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1530"/>
        <source>EFI System Partitions:</source>
        <translation>EFI rendszerpartíciók:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1543"/>
        <source>No EFI System Partition selected</source>
        <translation>Nincs kiválasztva EFI rendszerpartíció</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1550"/>
        <source>Could not mount selected EFI System Partition</source>
        <translation>A kiválasztott EFI rendszerpartíció csatolása nem sikerült</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1577"/>
        <location filename="../src/mainwindow.cpp" line="1621"/>
        <source>Could not mount partition. Please make sure you selected the correct partition.</source>
        <translation>Partíció csatolása sikertelen. Ellenőrzze, hogy a megfelelő partíciót választotta-e ki.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1586"/>
        <source>No directory selected</source>
        <translation>Nincs könyvtár kiválasztva</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1606"/>
        <location filename="../src/mainwindow.cpp" line="1643"/>
        <source>EFI stub installed successfully.</source>
        <translation>EFI csonk telepítése sikeres.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1608"/>
        <location filename="../src/mainwindow.cpp" line="1645"/>
        <source>Failed to install EFI stub.</source>
        <translation>EFI csonk telepítése nem sikerült.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1656"/>
        <source>Version: </source>
        <translation>Verzió:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1660"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1661"/>
        <source>%1 License</source>
        <translation>%1 licenc</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1669"/>
        <source>%1 Help</source>
        <translation>%1 súgó</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1697"/>
        <source>Something went wrong, could not save boot order.</source>
        <translation>Hiba történt, nem sikerült az indítási sorrend mentése.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1705"/>
        <source>Set timeout</source>
        <translation>Időtúllépés megadása</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1705"/>
        <source>Timeout in seconds:</source>
        <translation>Időtúllépés másodpercben:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1744"/>
        <source>Removal confirmation</source>
        <translation>Eltávolítás megerősítése</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1745"/>
        <source>Are you sure you want to delete this boot entry?
%1</source>
        <translation>Biztos, hogy törölni szeretné ezt az indítási lehetőséget?
%1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/about.cpp" line="99"/>
        <source>License</source>
        <translation>Licenc</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="100"/>
        <source>Changelog</source>
        <translation>Változások listája</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="101"/>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="125"/>
        <source>Error: Changelog file is missing.</source>
        <translation>Hiba: változási napló nem található.</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="127"/>
        <source>Error: Required utility &apos;zless&apos; is missing.</source>
        <translation>Hiba: a szükséges &apos;zless&apos; program nem található.</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="134"/>
        <source>&amp;Close</source>
        <translation>&amp;Bezárás</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="85"/>
        <source>uefi-manager is a tool for managing UEFI boot entries</source>
        <translation>Az uefi-manager egy eszköz UEFI rendszerindítási bejegyzések kezelésére</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="88"/>
        <source>Perform EFI Stub installation for frugal installation.</source>
        <translation>EFI csonk telepítésének elvégzése, lemezképként telepítéshez.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="66"/>
        <location filename="../src/main.cpp" line="95"/>
        <source>UEFI Manager</source>
        <translation>UEFI kezelő</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="89"/>
        <source>Run in test mode (bypass UEFI detection for GUI testing).</source>
        <translation>Futtatás teszt módban (kihagyja az UEFI érzékelést, csak kipróbálás).</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="96"/>
        <source>This system doesn&apos;t seem to support UEFI, or was not booted in UEFI mode. Exiting.</source>
        <translation>Ez a rendszer nem támogatja az UEFI-t, vagy nem UEFI módban került elindításra. Kilépés.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="107"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="108"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Úgy tűnik, hogy root felhasználóként van bejelentkezve. Jelentkezzen ki és jelentkezzen be egyszerű felhasználóként a program használatához.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="113"/>
        <source>version:</source>
        <translation>verzió:</translation>
    </message>
</context>
</TS>